euclidkit Documentation
=======================

.. image:: https://img.shields.io/badge/GitHub-rudolffu%2Feuclidkit-black?logo=github
   :target: https://github.com/rudolffu/euclidkit
   :alt: GitHub repository

.. image:: https://img.shields.io/pypi/v/euclidkit.svg
   :target: https://pypi.org/project/euclidkit/
   :alt: PyPI version

euclidkit is a toolkit for Euclid archival data analysis workflows, including
catalog crossmatch, spectra query/compilation, and cutout pipeline helpers.

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Guide

   installation
   configuration
   quickstart
   cli
   spectra_compilation
   api
